@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 use Carp ();
 use URI ();
@@ -292,10 +292,21 @@ sub video_id {
 sub playlist_id {
     my ($self, $stuff) = @_;
     return unless $stuff;
-    if ($stuff =~ m{/.*?[?&;!]list=PL([^&#?=/;]+)}) {
+    if ($stuff =~ m{/.*?[?&;!]list=([FP]L[^&#?=/;]+)}) {
+        return $1;
+    }
+    elsif ($stuff =~ m{^\s*([FP]L[\w\-]+)\s*$}) {
+        return $1;
+    }
+    return $stuff;
+}
+
+sub user_id {
+    my ($self, $stuff) = @_;
+    return unless $stuff;
+    if ($stuff =~ m{/user/([^&#?=/;]+)}) {
         return $1;
     }
-    $stuff =~ s/^PL//;
     return $stuff;
 }
 
@@ -478,6 +489,10 @@ Parses given URL and returns video ID.
 
 Parses given URL and returns playlist ID.
 
+=item B<user_id($url)>
+
+Parses given URL and returns YouTube username.
+
 =item B<get_video_url($video_id)>
 
 =item B<get_title($video_id)>
